@@ -2,15 +2,12 @@ import base64
 import hashlib
 from Crypto import Random
 from Crypto.Cipher import AES
-from typing import *
+from omnitools import *
 
 
 __ALL__ = ["AESCipher"]
 
 
-str_or_bytes = Union[str, bytes]
-
-
 class AESCipher(object):
     def __init__(self, key: str_or_bytes) -> None:
         if isinstance(key, str):
